#pysotsog
python Library for Scholars to achieve "Standing on the shoulders of giants"

[![GitHub issues](https://img.shields.io/github/issues/WolfgangFahl/pysotsog.svg)](https://github.com/WolfgangFahl/pysotsog/issues)
[![GitHub closed issues](https://img.shields.io/github/issues-closed/WolfgangFahl/pysotsog.svg)](https://github.com/WolfgangFahl/pysotsog/issues/?q=is%3Aissue+is%3Aclosed)
[![License](https://img.shields.io/github/license/WolfgangFahl/pysotsog.svg)](https://www.apache.org/licenses/LICENSE-2.0)

##Introduction
Jpysotsog is a python library for scholars to help navigate the conceptual knowledge graph consisting of

- authors
- organizations
- papers
- scientific events
- scientific event series

##Docs and Tutorials
[Wiki](https://wiki.bitplan.com/index.php/Pysotsog)
